==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebDragServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescription } from "./WebDragServiceDescription";
/**
 * @hidden
 */
var WebDragServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDragServiceDescriptionMetadata, _super);
    function WebDragServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDragServiceDescriptionMetadata.b = function (a) {
        if (WebDragServiceDescriptionMetadata.a == null) {
            WebDragServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDragServiceDescriptionMetadata.c(WebDragServiceDescriptionMetadata.a);
        }
        if (a.g(WebDragServiceDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDragServiceDescriptionMetadata.a);
    };
    WebDragServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DragService");
    };
    WebDragServiceDescriptionMetadata.d = function (a) {
        WebDragServiceDescriptionMetadata.b(a);
        a.u("WebDragService", function () { return new WebDragServiceDescription(); });
        a.t("WebDragService", WebDragServiceDescriptionMetadata.a);
    };
    WebDragServiceDescriptionMetadata.$t = markType(WebDragServiceDescriptionMetadata, 'WebDragServiceDescriptionMetadata');
    WebDragServiceDescriptionMetadata.a = null;
    return WebDragServiceDescriptionMetadata;
}(Base));
export { WebDragServiceDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebDragServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescription } from "./WebDragServiceDescription";
/**
 * @hidden
 */
var WebDragServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDragServiceDescriptionMetadata, _super);
    function WebDragServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDragServiceDescriptionMetadata.b = function (a) {
        if (WebDragServiceDescriptionMetadata.a == null) {
            WebDragServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDragServiceDescriptionMetadata.c(WebDragServiceDescriptionMetadata.a);
        }
        if (a.j(WebDragServiceDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDragServiceDescriptionMetadata.a);
    };
    WebDragServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DragService");
    };
    WebDragServiceDescriptionMetadata.d = function (a) {
        WebDragServiceDescriptionMetadata.b(a);
        a.aa("WebDragService", function () { return new WebDragServiceDescription(); });
        a.z("WebDragService", WebDragServiceDescriptionMetadata.a);
    };
    WebDragServiceDescriptionMetadata.$t = markType(WebDragServiceDescriptionMetadata, 'WebDragServiceDescriptionMetadata');
    WebDragServiceDescriptionMetadata.a = null;
    return WebDragServiceDescriptionMetadata;
}(Base));
export { WebDragServiceDescriptionMetadata };
